@@ -1,13 +1,13 @@
 
 # The R Commander and command logger
 
-# last modified 24 February 2009 by J. Fox
+# last modified 26 April 2009 by J. Fox
 #   slight changes 12 Aug 04 by Ph. Grosjean
 #   changes 21 June 2007 by Erich Neuwirth for Excel support (marked EN)
 # last modified 17 December 2008 by Richard Heiberger  ##rmh
 
 Commander <- function(){
-	RcmdrVersion <- "1.4-9"
+	RcmdrVersion <- "1.4-10"
 	##    DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 	##    RcmdrVersion <- trim.blanks(sub("^Version:", "",
 	##        grep("^Version:", D, value=TRUE)))
@@ -169,6 +169,7 @@ Commander <- function(){
 	setOption("output.text.color", "darkblue")
 	setOption("error.text.color", "red")
 	setOption("warning.text.color", "darkgreen")
+	setOption("prefixes", c("Rcmdr> ", "Rcmdr+ ", "RcmdrMsg: ", "RcmdrMsg+ "))
 	setOption("multiple.select.mode", "extended")
 	setOption("suppress.X11.warnings",
 		interactive() && .Platform$GUI == "X11") # to address problem in X11 (Linux or Mac OS X)
@@ -310,17 +311,18 @@ Commander <- function(){
 		tkfocus(CommanderWindow())
 	}
 	onView <- function(){
+		if (packageAvailable("relimp")) require("relimp")
 		if (activeDataSet() == FALSE) {
 			tkfocus(CommanderWindow())
 			return()
 		}
+		suppress <- if(getRcmdr("suppress.X11.warnings")) ", suppress.X11.warnings=FALSE" else ""
 		view.height <- max(as.numeric(output.height) + as.numeric(log.height), 10)
 		ncols <- ncol(get(ActiveDataSet()))
 #        ncols <- eval(parse(text=paste("ncol(", ActiveDataSet(), ")")))
 		command <- if (packageAvailable("relimp") && ncols <= getRcmdr("showData.threshold")){
-				require("relimp")
 				paste("showData(", ActiveDataSet(), ", placement='-20+200', font=getRcmdr('logFont'), maxwidth=",
-					log.width, ", maxheight=", view.height, ")", sep="")
+					log.width, ", maxheight=", view.height, suppress, ")", sep="")
 			}
 			else paste("View(", ActiveDataSet(), ")", sep="")
 		logger(command)
@@ -353,7 +355,7 @@ Commander <- function(){
 			while (nchar(lines[iline])==0) iline <- iline + 1
 			if (iline > nlines) break
 			current.line <- lines[iline]
-			if (.console.output) cat(paste("\nRcmdr> ", current.line,"\n", sep=""))
+			if (.console.output) cat(paste("\n", getRcmdr("prefixes")[1], current.line,"\n", sep=""))
 			else{
 				tkinsert(.output, "end", paste("\n> ", current.line,"\n", sep="")) ### end of changed
 				tktag.add(.output, "currentLine", "end - 2 lines linestart", "end - 2 lines lineend")
@@ -362,7 +364,7 @@ Commander <- function(){
 			jline <- iline + 1
 			while (jline <= nlines){
 				if (class(try(parse(text=current.line),silent=TRUE))!="try-error") break
-				if (.console.output)cat(paste("Rcmdr+ ", lines[jline],"\n", sep=""))
+				if (.console.output)cat(paste(getRcmdr("prefixes")[2], lines[jline],"\n", sep=""))
 				else{
 					tkinsert(.output, "end", paste("+ ", lines[jline],"\n", sep=""))
 					tktag.add(.output, "currentLine", "end - 2 lines linestart", "end - 2 lines lineend")
@@ -569,10 +571,10 @@ Commander <- function(){
 	tkbind(.commander, "<Control-X>", onCut)
 	tkbind(.commander, "<Control-c>", onCopy)
 	tkbind(.commander, "<Control-C>", onCopy)
-	if (.Platform$OS.type != "windows"){
-		tkbind(.commander, "<Control-v>", onPaste)
-		tkbind(.commander, "<Control-V>", onPaste)
-	}
+#	if (.Platform$OS.type != "windows"){
+#		tkbind(.commander, "<Control-v>", onPaste)
+#		tkbind(.commander, "<Control-V>", onPaste)
+#	}
 	tkbind(.commander, "<Control-r>", onSubmit)
 	tkbind(.commander, "<Control-R>", onSubmit)
 	tkbind(.commander, "<Control-Tab>", onSubmit)
@@ -618,7 +620,7 @@ logger <- function(command){
 	tkinsert(.output, "end", "\n")
 	if (getRcmdr("console.output")) {
 		for (line in seq(along=lines)) {
-			prompt <- ifelse (line==1, "\nRcmdr>", "\nRcmdr+")
+			prompt <- ifelse (line==1, paste("\n", getRcmdr("prefixes")[1], sep=""), paste("\n", getRcmdr("prefixes")[2], sep=""))
 			cat(paste(prompt, lines[line]))  ##rmh
 		}
 		cat("\n")                          ##rmh
@@ -731,8 +733,9 @@ doItAndPrint <- function(command, log=TRUE) {
 
 checkWarnings <- function(messages){
 	if (getRcmdr("suppress.X11.warnings")){
-		X11.warning <- grep("^Warning\\: X11 protocol error\\: BadWindow \\(invalid Window parameter\\)",
-			messages)
+#		X11.warning <- grep("^Warning\\: X11 protocol error\\: BadWindow \\(invalid Window parameter\\)",
+#			messages)
+		X11.warning <- grep("X11 protocol error|Warning in structure", messages)
 		if (length(X11.warning) > 0){
 			messages <- messages[-X11.warning]
 		}
@@ -804,7 +807,7 @@ Message <- function(message, type=c("note", "error", "warning")){
 	if (console.output) {                                        ##rmh & J. Fox
 		if (sink.number() != 0) sink()							## fixed by J. Fox
 		for (jline in seq(along=lines)) {                            ##rmh
-			Header <- if (jline==1) "RcmdrMsg: " else "RcmdrMsg+ "     ##rmh
+			Header <- if (jline==1) getRcmdr("prefixes")[3] else getRcmdr("prefixes")[4]     ##rmh
 			cat(paste(Header, lines[jline], "\n", sep=""))             ##rmh
 		}                                                            ##rmh
 	}                                                              ##rmh
